Builtin packages
================

Builtin packages are automatically added as dependencies when imported
from. They should not be added to the dependencies section in the
package configuration file.

Builtin packages are often tightly coupled to the transpiler and the
core Mys lib.
